#include <iostream>
#include <string>
#include <vector>
#include <algorithm>
#include <set>
#include <cmath>
#include <limits>
#include <cstring>
using namespace std;

#define MAX_N 100
#define QUANTIZE_MAX_N 10

int g_seq[MAX_N];
int g_seqCount;
int g_quantizeCount;
int g_INFINITE = numeric_limits<int>::max() / 2;

class Partition
{
	int _n;
	int _k;
	vector<int> _indexList;
	vector<int> _elements;

	int _cache[QUANTIZE_MAX_N][MAX_N];

	int _minSum = g_INFINITE;
	int _squareSumCache[MAX_N][MAX_N];

public:
	Partition(int elems[], int elemSize, int partitionCount)
	{
		_elements.insert(_elements.begin(), &elems[0], &elems[elemSize]);
		_n = elemSize;
		_k = partitionCount - 1;

		memset(_cache, -1, sizeof(int) * QUANTIZE_MAX_N * MAX_N);
		memset(_squareSumCache, -1, sizeof(int) * MAX_N * MAX_N);

		if (_k == 0)
		{
			_minSum = calcSquareSum(0, elemSize);
		}
		else
		{
			_indexList.resize(_k);

			int i = 0;
			for (i = 0; i < _k; i++)
			{
				_indexList[i] = i;
			}

			_indexList[i - 1] --;

			Enumerate();
		}
	}

	bool Enumerate()
	{
		int sum = 0;
		int startIndex = 0;
		int endIndex = _elements.size() - 1;

		int i;

		if (_indexList.size() == 0 || _indexList[0] == _n - _k)
		{
			return false;
		}

		for (i = _k - 1; i > 0 && _indexList[i] == _n - _k + i; i--)
		{
		}

		_indexList[i] ++;

		for (int j = i; j < _k - 1; j++)
		{
			_indexList[j + 1] = _indexList[j] + 1;
		}

		int cacheValue = GetCachePartialSum(i);
		
		for (int calcIndex = 0; calcIndex <= i; calcIndex++)
		{
			sum += calcSquareSum(startIndex, _indexList[calcIndex]);
			startIndex = _indexList[calcIndex];
		}

		int partialSum = 0;
		int squareSum = 0;

		if (cacheValue != -1)
		{
			squareSum = calcSquareSum(startIndex, _indexList[i + 1]);
			sum += squareSum;

			partialSum = cacheValue;
			sum += partialSum;
		}
		else
		{
			for (int calcIndex = i + 1; calcIndex < _indexList.size(); calcIndex++)
			{
				squareSum = calcSquareSum(startIndex, _indexList[calcIndex]);

				partialSum += squareSum;
				sum += squareSum;

				startIndex = _indexList[calcIndex];
			}

			squareSum = calcSquareSum(startIndex, endIndex + 1);
			partialSum += squareSum;
			sum += squareSum;
		}

		_minSum = min(_minSum, sum);
		
		CachePartialSum(partialSum);

		if (cacheValue != -1)
		{
			SkipIndex(i);
		}

		return true;
	}

	void SkipIndex(int cachePos)
	{
		int lastElem = _elements.size() - 1;
		for (int i = _indexList.size() - 1; i >= cachePos + 2; i --)
		{
			_indexList[i] = lastElem;
			lastElem--;
		}
	}

	int GetCachePartialSum(int &pos)
	{
		int cacheValue = -1;

		for (int i = _indexList.size() - 1; i >= 0; i--)
		{
			int value = _cache[i][_indexList[i]];

			if (value == -1)
			{
				break;
			}

			pos = i - 1;
			cacheValue = value;
		}

		return cacheValue;
	}

	void CachePartialSum(int partialSum)
	{
		int lastElem = _elements.size() - 1;
		bool firstLoop = true;
		for (int i = _indexList.size() - 1; i >= 0; i--)
		{
			if (firstLoop == true)
			{
				_cache[i][_indexList[i]] = partialSum;
				firstLoop = false;
			}

			if (_indexList[i] == lastElem)
			{
				if (i - 1 >= 0)
				{
					int parentIndex = _indexList[i - 1];
					int minPartial = g_INFINITE;

					for (int child = parentIndex + 1; child <= lastElem; child++)
					{
						int cacheValue = _cache[i][child];
						int squareSum = calcSquareSum(parentIndex, child);
						minPartial = min(minPartial, cacheValue + squareSum);
					}
					
					_cache[i - 1][_indexList[i - 1]] = minPartial;
				}
			}
			else
			{
				break;
			}

			lastElem--;
		}
	}

	int GetResult()
	{
		return _minSum;
	}

	int calcSquareSum(int start, int end)
	{
		if (start == end - 1 && end == _elements.size())
		{
			return 0;
		}

		int &sum = _squareSumCache[start][end];

		if (sum == -1)
		{
			int partialSum = 0;

			for (int i = start; i < end; i++)
			{
				partialSum += _elements[i];
			}

			int quantizeNumber = round(partialSum / ((double)end - start));

			int squareSum = 0;

			for (int i = start; i < end; i++)
			{
				int diff = (_elements[i] - quantizeNumber);
				squareSum += (diff * diff);
			}

			sum = squareSum;
		}

		return sum;
	}
};

// https://algospot.com/judge/problem/read/QUANTIZE
int main()
{
    int cases;
    cin >> cases;

    for (int i = 0; i < cases; i++)
    {
		int productSequare = 0;

		cin >> g_seqCount;
		cin >> g_quantizeCount;

		set<int> numbers;

		memset(g_seq, 0, sizeof(int) * MAX_N);

		for (int j = 0; j < g_seqCount; j++)
		{
			cin >> g_seq[j];
			numbers.insert(g_seq[j]);
		}

		if (numbers.size() <= g_quantizeCount)
		{
			cout << productSequare << endl;
			continue;
		}

		sort(g_seq, g_seq + g_seqCount);

		{
			Partition c(g_seq, g_seqCount, g_quantizeCount);

			while (c.Enumerate() == true);
			cout << c.GetResult() << endl;
		}
    }

    return 0;
}

